@@ -50,16 +50,39 @@ class DingDingPlugin(NotificationPlugin):
         access_token = self.get_option('access_token', group.project)
         send_url = DingTalk_API.format(token=access_token)
         title = "New alert from {}".format(event.project.slug)
-
+        event_url = "{0}events/{1}/".format(group.get_absolute_url(), event.id)
+        url_arr = event_url.split('/')
+        print(url_arr)
+        issue_id = url_arr[url_arr.index('issues') + 1]
+        print(issue_id)
+        issue_data = requests.get(
+            "http://web-middle.ruibogyl.work/sentry/findIssueTargetUrl",
+            {"id": issue_id},
+            headers={}
+        )
+        print issue_data
+        response = requests.get(
+            "http://web-middle.ruibogyl.work/sentry/getDingDingAssignee",
+            {"url": issue_data["data"]["url"]},
+            headers={}
+        ).json()
+        print response["data"]["phone"]
         data = {
             "msgtype": "markdown",
             "markdown": {
                 "title": title,
-                "text": u"#### {title} \n > {message} [href]({url})".format(
+                "text": "#### {title} \n > {message} \n [点击查看问题]({event_url}) \n @{phone}".format(
                     title=title,
                     message=event.message,
-                    url=u"{}events/{}/".format(group.get_absolute_url(), event.id),
-                )
+                    event_url=event_url,
+                    phone=response["data"]["phone"],
+                ),
+            },
+            "at": {
+                "atMobiles": [
+                    response["phone"]
+                ],
+                "isAtAll": False
             }
         }
         requests.post(
@@ -67,3 +90,4 @@ class DingDingPlugin(NotificationPlugin):
             headers={"Content-Type": "application/json"},
             data=json.dumps(data).encode("utf-8")
         )
+
